# 10EngineeringProblems
Programs designed to Solve Engineering Problems
To run each program just import the module using
`import 10EngrProblems`
Then to run each block of code just call *HW* then the number of the problem you are working on. 
As seen below this is how you would run HW1()
`HW1()`
